Contributing
============

- 💬 Discussions: https://github.com/uwplasma/JAX-in-Cell/discussions
- 🐛 Issues: https://github.com/uwplasma/JAX-in-Cell/issues
- 💡 Pull Requests: https://github.com/uwplasma/JAX-in-Cell/blob/main/CONTRIBUTING.md

Contributing Guidelines
-----------------------

1. Fork the repository.
2. Clone it:

   .. code-block:: console

       git clone https://github.com/uwplasma/JAX-in-Cell

3. Create a new branch:

   .. code-block:: console

       git checkout -b new-feature-x

4. Make and test changes.
5. Commit:

   .. code-block:: console

       git commit -m "Implemented new feature x."

6. Push:

   .. code-block:: console

       git push origin new-feature-x

7. Submit a pull request.
